@@ -5,6 +5,8 @@ import os
 import platform
 import ctypes.util
 import typing
+import setuptools.msvc
+import distutils.util
 import pefile
 import machomachomangler.pe
 from . import dll_list
@@ -22,6 +24,32 @@ class PEContext:
         self._pe.close()
 
 
+def find_library(name: str, wheel_dirs: typing.Optional[typing.Iterable]) -> typing.Optional[str]:
+    """Given the name of a DLL, return the path to the DLL, or None if the DLL
+    cannot be found. The search goes in the following order.
+    1. If not None, the directories in wheel_dirs.
+    2. The system search path via ctypes.util.find_library().
+    3. The compiler's runtime redistributable directory, if it exists."""
+    if wheel_dirs is not None:
+        for wheel_dir in wheel_dirs:
+            path = os.path.join(wheel_dir, name)
+            if os.path.isfile(path):
+                return path
+    path = ctypes.util.find_library(name)
+    if path is not None:
+        return path
+    try:
+        vcvars = setuptools.msvc.msvc14_get_vc_env(distutils.util.get_platform())
+        vcruntime = vcvars['py_vcruntime_redist']
+        redist_dir = os.path.dirname(vcruntime)
+        path = os.path.normpath(os.path.join(redist_dir, name))
+        if os.path.isfile(path):
+            return path
+        return None
+    except:
+        return None
+
+
 def get_direct_needed(lib_path: str, include_delay_imports: bool = True) -> set:
     """Given the path to a shared library, return a set containing the lowercase
     DLL names of all its direct dependencies.
@@ -73,6 +101,7 @@ def get_direct_mangleable_needed(lib_path: str, no_dlls: set, no_mangles: set) -
 def get_all_needed(lib_path: str,
                    add_dlls: set,
                    no_dlls: set,
+                   wheel_dirs: typing.Optional[typing.Iterable],
                    on_error: str = 'raise') -> typing.Tuple[typing.Set[str], typing.Set[str], typing.Set[str]]:
     """Given the path to a shared library, return a 3-tuple of sets
     (discovered, ignored, not_found).
@@ -95,7 +124,9 @@ def get_all_needed(lib_path: str,
 
     no_dlls is a set of DLL names to force exclusion from the wheel. We do not
     search for dependencies of these DLLs. Cannot overlap with add_dlls.
-    """
+
+    If wheel_dirs is not None, it is an iterable of directories in the wheel
+    where dependencies are searched first."""
     first_lib_path = lib_path.lower()
     stack = [first_lib_path]
     discovered = set()
@@ -110,7 +141,7 @@ def get_all_needed(lib_path: str,
                 lib_bitness = 64 if pe.FILE_HEADER.Machine == 34404 else 32
                 if interpreter_bitness != lib_bitness:
                     # bitness of Python interpreter must match that of the DLL
-                    # so that ctypes.util.find_library() can find it
+                    # so that find_library() can find it
                     raise OSError(f'Dependent library {lib_path} is {lib_bitness}-bit but Python interpreter is {interpreter_bitness}-bit')
 
                 imports = []
@@ -123,7 +154,7 @@ def get_all_needed(lib_path: str,
                     if dll_name not in ignore_names and \
                             not any(r.search(dll_name) for r in dll_list.ignore_regexes) and \
                             dll_name not in no_dlls:
-                        dll_path = ctypes.util.find_library(dll_name)
+                        dll_path = find_library(dll_name, wheel_dirs)
                         if dll_path:
                             stack.append(dll_path)
                         elif on_error == 'raise':
@@ -134,7 +165,7 @@ def get_all_needed(lib_path: str,
                         ignored.add(dll_name)
     discovered.remove(first_lib_path)
     for add_dll_name in add_dlls:
-        add_dll_path = ctypes.util.find_library(add_dll_name)
+        add_dll_path = find_library(add_dll_name, wheel_dirs)
         if add_dll_path:
             discovered.add(add_dll_path)
         elif on_error == 'raise':
